# Generated by ariadne-codegen
# Source: ../graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UnlockResources(BaseModel):
    unlock_resources: Optional["UnlockResourcesUnlockResources"] = Field(
        alias="unlockResources"
    )


class UnlockResourcesUnlockResources(BaseModel):
    success: Optional[bool]


UnlockResources.model_rebuild()
