# Generated by ariadne-codegen
# Source: ../graphql

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class TextFsmRender(BaseModel):
    text_fsm_render: Optional["TextFsmRenderTextFsmRender"] = Field(
        alias="textFsmRender"
    )


class TextFsmRenderTextFsmRender(BaseModel):
    rendered_template: Optional[Any] = Field(alias="renderedTemplate")
    error: Optional[str]


TextFsmRender.model_rebuild()
