# Generated by ariadne-codegen
# Source: ../graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class AddRole(BaseModel):
    role_upsert: Optional["AddRoleRoleUpsert"] = Field(alias="roleUpsert")


class AddRoleRoleUpsert(BaseModel):
    role: Optional["AddRoleRoleUpsertRole"]


class AddRoleRoleUpsertRole(BaseModel):
    id: str
    users: Optional[List[Optional["AddRoleRoleUpsertRoleUsers"]]]


class AddRoleRoleUpsertRoleUsers(BaseModel):
    id: str
    username: Optional[str]


AddRole.model_rebuild()
AddRoleRoleUpsert.model_rebuild()
AddRoleRoleUpsertRole.model_rebuild()
