# Generated by ariadne-codegen
# Source: ../graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class NeopsTaskCronjobDelete(BaseModel):
    neops_task_cronjob_delete: Optional[
        "NeopsTaskCronjobDeleteNeopsTaskCronjobDelete"
    ] = Field(alias="neopsTaskCronjobDelete")


class NeopsTaskCronjobDeleteNeopsTaskCronjobDelete(BaseModel):
    neops_task_cronjob: Optional[
        "NeopsTaskCronjobDeleteNeopsTaskCronjobDeleteNeopsTaskCronjob"
    ] = Field(alias="neopsTaskCronjob")


class NeopsTaskCronjobDeleteNeopsTaskCronjobDeleteNeopsTaskCronjob(BaseModel):
    id: str


NeopsTaskCronjobDelete.model_rebuild()
NeopsTaskCronjobDeleteNeopsTaskCronjobDelete.model_rebuild()
