# Generated by ariadne-codegen
# Source: ../graphql

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class NeopsTaskUnarchive(BaseModel):
    neops_task_upsert: Optional["NeopsTaskUnarchiveNeopsTaskUpsert"] = Field(
        alias="neopsTaskUpsert"
    )


class NeopsTaskUnarchiveNeopsTaskUpsert(BaseModel):
    neops_task: Optional["NeopsTaskUnarchiveNeopsTaskUpsertNeopsTask"] = Field(
        alias="neopsTask"
    )


class NeopsTaskUnarchiveNeopsTaskUpsertNeopsTask(BaseModel):
    id: str
    name: Optional[str]
    deleted_at: Optional[Any] = Field(alias="deletedAt")


NeopsTaskUnarchive.model_rebuild()
NeopsTaskUnarchiveNeopsTaskUpsert.model_rebuild()
