# Generated by ariadne-codegen
# Source: ../graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class Permissions(BaseModel):
    permissions: Optional["PermissionsPermissions"]


class PermissionsPermissions(BaseModel):
    results: Optional[List[Optional["PermissionsPermissionsResults"]]]


class PermissionsPermissionsResults(BaseModel):
    name: Optional[str]
    description: Optional[str]
    default_permission: Optional[int] = Field(alias="defaultPermission")
    default_permission_flags: Optional[List[Optional[str]]] = Field(
        alias="defaultPermissionFlags"
    )
    permission_all_flags: Optional[List[Optional[str]]] = Field(
        alias="permissionAllFlags"
    )
    permission: Optional[int]
    permission_flags: Optional[List[Optional[str]]] = Field(alias="permissionFlags")


Permissions.model_rebuild()
PermissionsPermissions.model_rebuild()
