# Generated by ariadne-codegen
# Source: ../graphql

from typing import List, Optional

from .base_model import BaseModel


class GetRole(BaseModel):
    role: Optional["GetRoleRole"]


class GetRoleRole(BaseModel):
    results: Optional[List[Optional["GetRoleRoleResults"]]]


class GetRoleRoleResults(BaseModel):
    id: str
    name: Optional[str]


GetRole.model_rebuild()
GetRoleRole.model_rebuild()
