# Generated by ariadne-codegen
# Source: ../graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class RolePermissionUpsert(BaseModel):
    role_permission_upsert: Optional["RolePermissionUpsertRolePermissionUpsert"] = (
        Field(alias="rolePermissionUpsert")
    )


class RolePermissionUpsertRolePermissionUpsert(BaseModel):
    role_permission: Optional[
        "RolePermissionUpsertRolePermissionUpsertRolePermission"
    ] = Field(alias="rolePermission")


class RolePermissionUpsertRolePermissionUpsertRolePermission(BaseModel):
    id: str
    default_permission_flags: Optional[List[Optional[str]]] = Field(
        alias="defaultPermissionFlags"
    )


RolePermissionUpsert.model_rebuild()
RolePermissionUpsertRolePermissionUpsert.model_rebuild()
