# Generated by ariadne-codegen
# Source: ../graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class ReportsExecute(BaseModel):
    reports_execute: Optional["ReportsExecuteReportsExecute"] = Field(
        alias="reportsExecute"
    )


class ReportsExecuteReportsExecute(BaseModel):
    report_execution: Optional["ReportsExecuteReportsExecuteReportExecution"] = Field(
        alias="reportExecution"
    )


class ReportsExecuteReportsExecuteReportExecution(BaseModel):
    content_base_64: Optional[str] = Field(alias="contentBase64")
    extension: Optional[str]


ReportsExecute.model_rebuild()
ReportsExecuteReportsExecute.model_rebuild()
