# Generated by ariadne-codegen
# Source: ../graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class RoleNeopsTask(BaseModel):
    role_neops_task: Optional["RoleNeopsTaskRoleNeopsTask"] = Field(
        alias="roleNeopsTask"
    )


class RoleNeopsTaskRoleNeopsTask(BaseModel):
    results: Optional[List[Optional["RoleNeopsTaskRoleNeopsTaskResults"]]]


class RoleNeopsTaskRoleNeopsTaskResults(BaseModel):
    id: str
    role: Optional["RoleNeopsTaskRoleNeopsTaskResultsRole"]
    neops_task: Optional["RoleNeopsTaskRoleNeopsTaskResultsNeopsTask"] = Field(
        alias="neopsTask"
    )


class RoleNeopsTaskRoleNeopsTaskResultsRole(BaseModel):
    id: str
    name: Optional[str]


class RoleNeopsTaskRoleNeopsTaskResultsNeopsTask(BaseModel):
    id: str
    name: Optional[str]


RoleNeopsTask.model_rebuild()
RoleNeopsTaskRoleNeopsTask.model_rebuild()
RoleNeopsTaskRoleNeopsTaskResults.model_rebuild()
