# Generated by ariadne-codegen
# Source: ../graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class CronjobTypes(BaseModel):
    cronjob_type: Optional["CronjobTypesCronjobType"] = Field(alias="cronjobType")


class CronjobTypesCronjobType(BaseModel):
    results: Optional[List[Optional["CronjobTypesCronjobTypeResults"]]]


class CronjobTypesCronjobTypeResults(BaseModel):
    id: str
    name: Optional[str]
    description: Optional[str]
    task: Optional[str]
    args: Optional[Any]
    custom_args_from: Optional[Any] = Field(alias="customArgsFrom")


CronjobTypes.model_rebuild()
CronjobTypesCronjobType.model_rebuild()
