# Generated by ariadne-codegen
# Source: ../graphql

from typing import List, Optional

from .base_model import BaseModel


class Platforms(BaseModel):
    platforms: Optional["PlatformsPlatforms"]


class PlatformsPlatforms(BaseModel):
    results: Optional[List[Optional["PlatformsPlatformsResults"]]]


class PlatformsPlatformsResults(BaseModel):
    id: str
    name: Optional[str]


Platforms.model_rebuild()
PlatformsPlatforms.model_rebuild()
