# Generated by ariadne-codegen
# Source: ../graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class DeviceAggregation(BaseModel):
    device_aggregation: Optional["DeviceAggregationDeviceAggregation"] = Field(
        alias="deviceAggregation"
    )


class DeviceAggregationDeviceAggregation(BaseModel):
    results: Optional[List[Optional["DeviceAggregationDeviceAggregationResults"]]]
    count_aggregated_elements: Optional[int] = Field(alias="countAggregatedElements")
    count: Optional[int]


class DeviceAggregationDeviceAggregationResults(BaseModel):
    value: Optional[str]
    count: Optional[int]


DeviceAggregation.model_rebuild()
DeviceAggregationDeviceAggregation.model_rebuild()
