# Generated by ariadne-codegen
# Source: ../graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class NeopsTaskCreateMutation(BaseModel):
    neops_task_upsert: Optional["NeopsTaskCreateMutationNeopsTaskUpsert"] = Field(
        alias="neopsTaskUpsert"
    )


class NeopsTaskCreateMutationNeopsTaskUpsert(BaseModel):
    neops_task: Optional["NeopsTaskCreateMutationNeopsTaskUpsertNeopsTask"] = Field(
        alias="neopsTask"
    )


class NeopsTaskCreateMutationNeopsTaskUpsertNeopsTask(BaseModel):
    id: str
    name: Optional[str]


NeopsTaskCreateMutation.model_rebuild()
NeopsTaskCreateMutationNeopsTaskUpsert.model_rebuild()
