# Generated by ariadne-codegen
# Source: ../graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class JinjaRender(BaseModel):
    jinja_render: Optional["JinjaRenderJinjaRender"] = Field(alias="jinjaRender")


class JinjaRenderJinjaRender(BaseModel):
    rendered_template: Optional[str] = Field(alias="renderedTemplate")
    error: Optional[str]


JinjaRender.model_rebuild()
