# Generated by ariadne-codegen
# Source: ../graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class NeopsTaskCronjobUpsert(BaseModel):
    neops_task_cronjob_upsert: Optional[
        "NeopsTaskCronjobUpsertNeopsTaskCronjobUpsert"
    ] = Field(alias="neopsTaskCronjobUpsert")


class NeopsTaskCronjobUpsertNeopsTaskCronjobUpsert(BaseModel):
    neops_task_cronjob: Optional[
        "NeopsTaskCronjobUpsertNeopsTaskCronjobUpsertNeopsTaskCronjob"
    ] = Field(alias="neopsTaskCronjob")


class NeopsTaskCronjobUpsertNeopsTaskCronjobUpsertNeopsTaskCronjob(BaseModel):
    id: str
    name: Optional[str]


NeopsTaskCronjobUpsert.model_rebuild()
NeopsTaskCronjobUpsertNeopsTaskCronjobUpsert.model_rebuild()
