# Generated by ariadne-codegen
# Source: ../graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class ScopeDelete(BaseModel):
    scope_delete: Optional["ScopeDeleteScopeDelete"] = Field(alias="scopeDelete")


class ScopeDeleteScopeDelete(BaseModel):
    scope: Optional["ScopeDeleteScopeDeleteScope"]


class ScopeDeleteScopeDeleteScope(BaseModel):
    id: str


ScopeDelete.model_rebuild()
ScopeDeleteScopeDelete.model_rebuild()
