# Generated by ariadne-codegen
# Source: ../graphql

from typing import List, Optional

from .base_model import BaseModel


class RoleUser(BaseModel):
    role: Optional["RoleUserRole"]


class RoleUserRole(BaseModel):
    results: Optional[List[Optional["RoleUserRoleResults"]]]


class RoleUserRoleResults(BaseModel):
    id: str
    name: Optional[str]


RoleUser.model_rebuild()
RoleUserRole.model_rebuild()
