# Generated by ariadne-codegen
# Source: ../graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class InterfaceAggregation(BaseModel):
    interface_aggregation: Optional["InterfaceAggregationInterfaceAggregation"] = Field(
        alias="interfaceAggregation"
    )


class InterfaceAggregationInterfaceAggregation(BaseModel):
    results: Optional[List[Optional["InterfaceAggregationInterfaceAggregationResults"]]]
    count_aggregated_elements: Optional[int] = Field(alias="countAggregatedElements")
    count: Optional[int]


class InterfaceAggregationInterfaceAggregationResults(BaseModel):
    value: Optional[str]
    count: Optional[int]


InterfaceAggregation.model_rebuild()
InterfaceAggregationInterfaceAggregation.model_rebuild()
