# Generated by ariadne-codegen
# Source: ../graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class AddUser(BaseModel):
    local_user_create: Optional["AddUserLocalUserCreate"] = Field(
        alias="localUserCreate"
    )


class AddUserLocalUserCreate(BaseModel):
    local_user: Optional["AddUserLocalUserCreateLocalUser"] = Field(alias="localUser")


class AddUserLocalUserCreateLocalUser(BaseModel):
    id: str
    username: Optional[str]
    password: Optional[str]
    is_active: Optional[bool] = Field(alias="isActive")
    is_superuser: Optional[bool] = Field(alias="isSuperuser")
    first_name: Optional[str] = Field(alias="firstName")
    last_name: Optional[str] = Field(alias="lastName")


AddUser.model_rebuild()
AddUserLocalUserCreate.model_rebuild()
