# Generated by ariadne-codegen
# Source: ../graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class RolePermissionElement(BaseModel):
    role_permission_element: Optional["RolePermissionElementRolePermissionElement"] = (
        Field(alias="rolePermissionElement")
    )


class RolePermissionElementRolePermissionElement(BaseModel):
    results: Optional[
        List[Optional["RolePermissionElementRolePermissionElementResults"]]
    ]


class RolePermissionElementRolePermissionElementResults(BaseModel):
    id: str
    permission_element: Optional[
        "RolePermissionElementRolePermissionElementResultsPermissionElement"
    ] = Field(alias="permissionElement")


class RolePermissionElementRolePermissionElementResultsPermissionElement(BaseModel):
    id: str
    name: Optional[str]
    description: Optional[str]


RolePermissionElement.model_rebuild()
RolePermissionElementRolePermissionElement.model_rebuild()
RolePermissionElementRolePermissionElementResults.model_rebuild()
