# Generated by ariadne-codegen
# Source: ../graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class AppSettings(BaseModel):
    app_settings: Optional["AppSettingsAppSettings"] = Field(alias="appSettings")


class AppSettingsAppSettings(BaseModel):
    auth: Optional["AppSettingsAppSettingsAuth"]
    modules: Optional[List[Optional["AppSettingsAppSettingsModules"]]]
    sentry: Optional["AppSettingsAppSettingsSentry"]
    version: Optional[str]
    use_oidc: Optional[bool] = Field(alias="useOidc")
    oidc_config: Optional[Any] = Field(alias="oidcConfig")


class AppSettingsAppSettingsAuth(BaseModel):
    active: Optional[bool]
    type: Optional[str]


class AppSettingsAppSettingsModules(BaseModel):
    name: Optional[str]


class AppSettingsAppSettingsSentry(BaseModel):
    dsn: Optional[str]
    environment: Optional[str]


AppSettings.model_rebuild()
AppSettingsAppSettings.model_rebuild()
