# Generated by ariadne-codegen
# Source: ../graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class AutocompleteFields(BaseModel):
    search_fields: Optional[List[Optional[str]]] = Field(alias="searchFields")
