# Generated by ariadne-codegen
# Source: ../graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class RolePermissionElementUpsert(BaseModel):
    role_permission_element_upsert: Optional[
        "RolePermissionElementUpsertRolePermissionElementUpsert"
    ] = Field(alias="rolePermissionElementUpsert")


class RolePermissionElementUpsertRolePermissionElementUpsert(BaseModel):
    role_permission_element: Optional[
        "RolePermissionElementUpsertRolePermissionElementUpsertRolePermissionElement"
    ] = Field(alias="rolePermissionElement")


class RolePermissionElementUpsertRolePermissionElementUpsertRolePermissionElement(
    BaseModel
):
    id: str
    permission_flags: Optional[List[Optional[str]]] = Field(alias="permissionFlags")


RolePermissionElementUpsert.model_rebuild()
RolePermissionElementUpsertRolePermissionElementUpsert.model_rebuild()
