# Generated by ariadne-codegen
# Source: ../graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class RoleNeopsTaskUpsert(BaseModel):
    role_neops_task_upsert: Optional["RoleNeopsTaskUpsertRoleNeopsTaskUpsert"] = Field(
        alias="roleNeopsTaskUpsert"
    )


class RoleNeopsTaskUpsertRoleNeopsTaskUpsert(BaseModel):
    role_neops_task: Optional["RoleNeopsTaskUpsertRoleNeopsTaskUpsertRoleNeopsTask"] = (
        Field(alias="roleNeopsTask")
    )


class RoleNeopsTaskUpsertRoleNeopsTaskUpsertRoleNeopsTask(BaseModel):
    id: str
    permission_flags: Optional[List[Optional[str]]] = Field(alias="permissionFlags")


RoleNeopsTaskUpsert.model_rebuild()
RoleNeopsTaskUpsertRoleNeopsTaskUpsert.model_rebuild()
